const root = "https://cdn.skypack.dev";
/** 获取 package 的文件 */
export const getPackageURL = (name, path = "", { min = false, dts = false, dist } = {}) => {
    const params = new URLSearchParams();
    min && params.set("min", "");
    dts && params.set("dts", "");
    dist && params.set("dts", dist);
    return root + `/${name}/` + path + "?" + params.toString();
};
/**
 * 获取 package 的详细信息 当构建失败时会报错
 * https://docs.skypack.dev/skypack-cdn/api-reference/package-metadata */
export const getPackageMetaData = async (name) => {
    return fetch(root + `/${name}?meta`).then((res) => res.json());
};
/**
 * 获取一个 pinned 的 URL，可以加速获取文件
 * https://docs.skypack.dev/skypack-cdn/api-reference/pinned-urls-optimized
 */
export const getPinnedURL = async (name, min = false) => {
    const meta = await getPackageMetaData(name);
    if (meta.packageExports["."]) {
        const head = root +
            `/pin/${meta.name}@v${meta.version}-${meta.buildId}/mode=imports${min ? ",min" : ""}/optimized/`;
        return head + meta.packageExports["."].id.replace(/^\.*\//, "");
    }
    else {
        return "";
    }
};
